@@ -1,6 +1,6 @@
 from .base import *
 from .hostname import *
 from .include import *
-from .remote import *
 from .parse import *
-from .utils import CONFIG, find_vcs_root, find_repo_root
+from .remote import *
+from .utils import CONFIG, find_repo_root, find_vcs_root
